module.exports = defineTest({
	description: 'handles unary expression side-effects'
});
